==> zio-aws-kafka_3-5.17.104.8-sources.jar: zio/aws/kafka/model/UpdateBrokerTypeRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class UpdateBrokerTypeRequest(
    clusterArn: __string,
    currentVersion: __string,
    targetInstanceType: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.UpdateBrokerTypeRequest = {
    import UpdateBrokerTypeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.UpdateBrokerTypeRequest
      .builder()
      .clusterArn(__string.unwrap(clusterArn): java.lang.String)
      .currentVersion(__string.unwrap(currentVersion): java.lang.String)
      .targetInstanceType(__string.unwrap(targetInstanceType): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.UpdateBrokerTypeRequest.ReadOnly =
    zio.aws.kafka.model.UpdateBrokerTypeRequest.wrap(buildAwsValue())
}
object UpdateBrokerTypeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.UpdateBrokerTypeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.UpdateBrokerTypeRequest =
      zio.aws.kafka.model
        .UpdateBrokerTypeRequest(clusterArn, currentVersion, targetInstanceType)
    def clusterArn: __string
    def currentVersion: __string
    def targetInstanceType: __string
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
    def getCurrentVersion: ZIO[Any, Nothing, __string] =
      ZIO.succeed(currentVersion)
    def getTargetInstanceType: ZIO[Any, Nothing, __string] =
      ZIO.succeed(targetInstanceType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.UpdateBrokerTypeRequest
  ) extends zio.aws.kafka.model.UpdateBrokerTypeRequest.ReadOnly {
    override val clusterArn: __string =
      zio.aws.kafka.model.primitives.__string(impl.clusterArn())
    override val currentVersion: __string =
      zio.aws.kafka.model.primitives.__string(impl.currentVersion())
    override val targetInstanceType: __string =
      zio.aws.kafka.model.primitives.__string(impl.targetInstanceType())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.UpdateBrokerTypeRequest
  ): zio.aws.kafka.model.UpdateBrokerTypeRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_3-6.20.103.1-sources.jar: zio/aws/kafka/model/UpdateBrokerTypeRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class UpdateBrokerTypeRequest(
    clusterArn: __string,
    currentVersion: __string,
    targetInstanceType: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.UpdateBrokerTypeRequest = {
    import UpdateBrokerTypeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.UpdateBrokerTypeRequest
      .builder()
      .clusterArn(clusterArn: java.lang.String)
      .currentVersion(currentVersion: java.lang.String)
      .targetInstanceType(targetInstanceType: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.UpdateBrokerTypeRequest.ReadOnly =
    zio.aws.kafka.model.UpdateBrokerTypeRequest.wrap(buildAwsValue())
}
object UpdateBrokerTypeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.UpdateBrokerTypeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.UpdateBrokerTypeRequest =
      zio.aws.kafka.model
        .UpdateBrokerTypeRequest(clusterArn, currentVersion, targetInstanceType)
    def clusterArn: __string
    def currentVersion: __string
    def targetInstanceType: __string
    def getClusterArn: ZIO[Any, Nothing, __string] = ZIO.succeed(clusterArn)
    def getCurrentVersion: ZIO[Any, Nothing, __string] =
      ZIO.succeed(currentVersion)
    def getTargetInstanceType: ZIO[Any, Nothing, __string] =
      ZIO.succeed(targetInstanceType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.UpdateBrokerTypeRequest
  ) extends zio.aws.kafka.model.UpdateBrokerTypeRequest.ReadOnly {
    override val clusterArn: __string = impl.clusterArn(): __string
    override val currentVersion: __string = impl.currentVersion(): __string
    override val targetInstanceType: __string =
      impl.targetInstanceType(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.UpdateBrokerTypeRequest
  ): zio.aws.kafka.model.UpdateBrokerTypeRequest.ReadOnly = new Wrapper(impl)
}
